@@ -4,7 +4,7 @@ for (dis)aggregation of data.
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-__version__ = "0.2.9"
+__version__ = "0.5.0"
 __title__ = "Data Disaggregation"
 __author__ = "Christian Winger"
 __email__ = "c.winger@oeko.de"
@@ -12,7 +12,7 @@ __copyright__ = "MIT"
 __url__ = "https://github.com/wingechr/data-disaggregation"
 
 try:
-    from . import draw
+    from . import draw, exceptions
     from .classes import (
         Dimension,
         DimensionLevel,
